@@ -48,10 +48,19 @@ setMethod("rebuild_CRS", signature(obj = "CRS"),
         if (requireNamespace("sf", quietly = TRUE)) {
             if ((is.na(projargs) && !is.null(SRS_string))) {
                 res <- sf::st_crs(SRS_string)
+                res <- as(res, "CRS")
             } else {
                 res <- sf::st_crs(projargs)
+                res1 <- try(as(res, "CRS"), silent=TRUE)
+                if (inherits(res1, "try-error")) {
+                    res <- new("CRS", projargs=projargs)
+                    warning("invalid PROJ4 string")
+# rbgm workaround for +proj=utm +zone=18 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs +# +a=6378137.0 +es=0.006694380022900787 +lon_0=-75d00 +lat_0=0d00 +x_0=500000.0 +y_0=0.0 +k=0.9996 in bgmfiles Final_CAM_Boxes_8.bgm
+                } else {
+                    res <- res1
+                }
             }
-            return(as(res, "CRS"))
+            return(res)
         } else {
             warning("sf required for evolution_status==2L")
         }
